@@ -124,7 +124,7 @@ QColor Canvas::rgbDoublesToColor(double r, double g, double b)
 void Canvas::drawLine(double x1, double y1, double x2, double y2)
 {
 	if (penWidthIsZero) return;
-	QGraphicsLineItem* line = new QGraphicsLineItem(QLineF(x1, y1, x2, y2), 0);
+	QGraphicsLineItem* line = new QGraphicsLineItem(QLineF(x1, y1, x2, y2), nullptr);
 	_scene->addItem(line);
 	line->setPen(*pen);
 	lines.append(line);
